Baidubaike
##########

**baidubaike** 是一个百度百科词条内容的简单封装。


Installation
============

::

    $ pip install baidubaike


Examples
========


License
=======
`MIT Licensed. <https://github.com/yakiang/Baidubaike/blob/master/LICENSE>`_


Thanks to
=========

* `goldsmith/Wikipedia <https://github.com/goldsmith/Wikipedia>`_
* `百度百科 <http://baike.baidu.com>`_


